@@ -1,8 +1,8 @@
 package Glitch;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use 5.006; use strict; use warnings;
 use Data::Dumper; use feature qw/state/;
-state %GLITCHES;
+state (%GLITCHES, $LOGGER, $LOGGER_ENABLED, $LOGGER_FORMAT, $LOGGER_METHOD, %STRINGIFY, $STRINGIFY_FORMAT);
 
 BEGIN {
         $Data::Dumper::Deparse = 1;
@@ -11,6 +11,15 @@ BEGIN {
 sub import {
 	my ($pkg, %import) = @_;
 	if (keys %import) {
+		if ($import{glitch_logger}) {
+			$LOGGER = delete $import{glitch_logger};
+			$LOGGER_ENABLED = !!1;
+		}
+		$LOGGER_ENABLED = delete $import{glitch_logger_enabled} if defined $import{glitch_logger_enabled};
+		$LOGGER_FORMAT = delete $import{glitch_logger_format} if defined $import{glitch_logger_format};
+		$LOGGER_METHOD = delete $import{glitch_logger_method} if defined $import{glitch_logger_method};
+		%STRINGIFY = (%STRINGIFY, %{ delete $import{glitch_stringify} }) if defined $import{glitch_stringify};
+		$STRINGIFY_FORMAT = delete $import{glitch_stringify_format} if defined $import{glitch_stringify_format};
 		_build_glitch(
 			name => $_,
 			%{ $import{$_} },
@@ -30,18 +39,47 @@ sub glitch {
 		_stack(),
 		@_
 	);
-
 	_build_glitch(%options) if (!$GLITCHES{$options{name}});
-
-	die $GLITCHES{$options{name}}->new(%options);
+	die _log($GLITCHES{$options{name}}->new(%options));
 }
 
+sub logger {
+	$LOGGER = $_[0];
+}
+
+sub logger_enabled {
+	$LOGGER_ENABLED = !!$_[0];
+}
+
+sub logger_format {
+	$LOGGER_FORMAT = $_[0];
+}
+
+sub logger_method {
+	$LOGGER_METHOD = $_[0];
+}
+
+sub _log {
+	if ($LOGGER_ENABLED && $LOGGER) {
+		my $ref = ref $LOGGER;
+		my $glitch = $LOGGER_FORMAT ? $_[0]->stringify($LOGGER_FORMAT) : $_[0];
+		$LOGGER_METHOD ||= 'err';
+		($ref eq 'CODE') ? $LOGGER->($glitch) : $LOGGER->$LOGGER_METHOD($glitch);
+	}
+	return $_[0];
+}
+
+
 sub _build_glitch {
 	my (%options) = @_;
 	my $class = sprintf q|%s::%s|, $options{object_name} ||= 'Glitch', $options{name};
 	my @methods = map { my $struct = $_ =~ m/(file|filepath|line|stacktrace|module)/ ? "''" :  _stringify_struct($options{$_}); "sub $_ { return \$_[0]->{$_} || $struct; }" } sort keys %options;
 	unshift @methods, 'sub new { my $self = shift; return bless {@_}, $self; }';
-	push @methods, 'sub stringify { return $_[0]->message . " at " . $_[0]->filepath . " line " . $_[0]->line . "\n"; }';
+	$STRINGIFY_FORMAT ||= 'default';
+	push @methods, 'sub stringify { my $type = sprintf "stringify_%s", ($_[1] || "' . $STRINGIFY_FORMAT . '"); return $_[0]->$type(); }';
+	$STRINGIFY{default} ||= 'return $_[0]->message . " at " . $_[0]->filepath . " line " . $_[0]->line . "\n";';
+	$STRINGIFY{json} ||= 'require JSON; JSON->new->encode({%{$_[0]}});';
+	push @methods, sprintf "sub stringify_%s { %s }", $_, $STRINGIFY{$_} for sort keys %STRINGIFY;
 	my $package = sprintf(q|package %s;
 use overload '""' => \&stringify;
 %s
@@ -92,7 +130,7 @@ Glitch - Exception Handling.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
@@ -143,6 +181,12 @@ Version 0.04
 	package Glitches;
 
 	use Glitch (
+		glitch_logger => sub {
+			open my $fh, '>', 'glitch.log';
+			print $fh $_[0] . "\n";
+			close $fh;	
+		},
+		glitch_stringify_format => 'json',
 		one => {
 			message => 'Create a new glitch error message'
 		},
